Module: Google::Apis::FirebasecrashlyticsV1alpha

Defined in:
lib/google/apis/firebasecrashlytics_v1alpha.rb,
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/service.rb,
lib/google/apis/firebasecrashlytics_v1alpha/gem_version.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

Firebase Crashlytics API

This service provides an API for mobile app developers to request deletion of user's crash reports.

Defined Under Namespace

Classes: BatchGetEventsResponse, BatchUpdateIssuesRequest, BatchUpdateIssuesResponse, Breadcrumb, Browser, DeleteUserCrashReportsResponse, Device, Empty, Error, Event, Exception, FirebaseCrashlyticsService, FirebaseSessionEvent, Frame, IntervalMetrics, Issue, IssueSignals, IssueVariant, ListEventsResponse, ListNotesResponse, ListReportsResponse, Log, Memory, Note, OperatingSystem, PlayTrack, Report, ReportGroup, Storage, Thread, UpdateIssueRequest, User, Version, WebMetricsGroup

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-firebasecrashlytics_v1alpha gem

"0.1.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.19.0"
REVISION =

Revision of the discovery document this client was generated from

"20260710"
VERSION =

Version of the Firebase Crashlytics API this client connects to. This is NOT the gem version.

'V1alpha'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'
AUTH_FIREBASE =

View and administer all your Firebase data and settings

'https://www.googleapis.com/auth/firebase'