Class: Google::Apis::FirebasecrashlyticsV1alpha::BatchUpdateIssuesResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::BatchUpdateIssuesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
Response message for the BatchUpdateIssues method.
Instance Attribute Summary collapse
-
#issues ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Issue>
Issues updated in the same order as in BatchUpdateIssuesRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateIssuesResponse
constructor
A new instance of BatchUpdateIssuesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchUpdateIssuesResponse
Returns a new instance of BatchUpdateIssuesResponse.
81 82 83 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 81 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issues ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Issue>
Issues updated in the same order as in BatchUpdateIssuesRequest.
Corresponds to the JSON property issues
79 80 81 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 79 def issues @issues end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
86 87 88 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 86 def update!(**args) @issues = args[:issues] if args.key?(:issues) end |