Class: Google::Apis::FirebasecrashlyticsV1alpha::DeleteUserCrashReportsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

Response message for the DeleteUserCrashReports method. All crash reports associated with the specified user will be deleted typically within 24 hours of receiving the crash report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteUserCrashReportsResponse

Returns a new instance of DeleteUserCrashReportsResponse.



165
166
167
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_complete_timeString

Target time to complete the delete crash reports operation. Corresponds to the JSON property targetCompleteTime

Returns:

  • (String)


163
164
165
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 163

def target_complete_time
  @target_complete_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



170
171
172
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 170

def update!(**args)
  @target_complete_time = args[:target_complete_time] if args.key?(:target_complete_time)
end