Class: Google::Apis::FirebasecrashlyticsV1alpha::Exception
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::Exception
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
A Java or Javascript exception and its stacktrace. Only from Android or web apps.
Instance Attribute Summary collapse
-
#blamed ⇒ Boolean
(also: #blamed?)
True when the Crashlytics analysis has determined that this thread is where the fault occurred.
-
#exception_message ⇒ String
A message associated with the exception.
-
#frames ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Frame>
The frames in the exception's stacktrace.
-
#nested ⇒ Boolean
(also: #nested?)
True for all but the last-thrown exception (i.e. the first record).
-
#subtitle ⇒ String
The subtitle of the exception.
-
#title ⇒ String
The title of the exception.
-
#type ⇒ String
The exception type e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Exception
constructor
A new instance of Exception.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Exception
Returns a new instance of Exception.
566 567 568 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blamed ⇒ Boolean Also known as: blamed?
True when the Crashlytics analysis has determined that this thread is where
the fault occurred.
Corresponds to the JSON property blamed
532 533 534 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 532 def blamed @blamed end |
#exception_message ⇒ String
A message associated with the exception.
Corresponds to the JSON property exceptionMessage
538 539 540 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 538 def @exception_message end |
#frames ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Frame>
The frames in the exception's stacktrace.
Corresponds to the JSON property frames
543 544 545 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 543 def frames @frames end |
#nested ⇒ Boolean Also known as: nested?
True for all but the last-thrown exception (i.e. the first record).
Corresponds to the JSON property nested
548 549 550 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 548 def nested @nested end |
#subtitle ⇒ String
The subtitle of the exception.
Corresponds to the JSON property subtitle
554 555 556 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 554 def subtitle @subtitle end |
#title ⇒ String
The title of the exception.
Corresponds to the JSON property title
559 560 561 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 559 def title @title end |
#type ⇒ String
The exception type e.g. java.lang.IllegalStateException.
Corresponds to the JSON property type
564 565 566 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 564 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
571 572 573 574 575 576 577 578 579 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 571 def update!(**args) @blamed = args[:blamed] if args.key?(:blamed) @exception_message = args[:exception_message] if args.key?(:exception_message) @frames = args[:frames] if args.key?(:frames) @nested = args[:nested] if args.key?(:nested) @subtitle = args[:subtitle] if args.key?(:subtitle) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |