Class: Google::Apis::FirebasecrashlyticsV1alpha::FirebaseCrashlyticsService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/service.rb

Overview

Firebase Crashlytics API

This service provides an API for mobile app developers to request deletion of user's crash reports.

Examples:

require 'google/apis/firebasecrashlytics_v1alpha'

Firebasecrashlytics = Google::Apis::FirebasecrashlyticsV1alpha # Alias the module
service = Firebasecrashlytics::FirebaseCrashlyticsService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://firebasecrashlytics.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeFirebaseCrashlyticsService

Returns a new instance of FirebaseCrashlyticsService.



48
49
50
51
52
53
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 48

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-firebasecrashlytics_v1alpha',
        client_version: Google::Apis::FirebasecrashlyticsV1alpha::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



41
42
43
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 41

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



46
47
48
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 46

def quota_user
  @quota_user
end

Instance Method Details

#batch_project_app_event_get(parent, names: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::BatchGetEventsResponse

Fetch a batch of up to 100 events by name.

Parameters:

  • parent (String)

    Required. The firebase application. Format: "projects/project/apps/app_id".

  • names (Array<String>, String) (defaults to: nil)

    Required. The resource names of the desired events. A maximum of 100 events can be retrieved in a batch. Format: "projects/project/apps/app_id/events/ event_id". The app_id and event_id are required, but project may be "-" to conserve space in long URIs.

  • read_mask (String) (defaults to: nil)

    Optional. The list of Event fields to include in the response. If omitted, the full event is returned.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



83
84
85
86
87
88
89
90
91
92
93
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 83

def batch_project_app_event_get(parent, names: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/events:batchGet', options)
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::BatchGetEventsResponse::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::BatchGetEventsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['names'] = names unless names.nil?
  command.query['readMask'] = read_mask unless read_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#batch_update_issues(parent, batch_update_issues_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::BatchUpdateIssuesResponse

Change the state of a group of issues. This method is not atomic, so partial failures can occur. In the event of a partial failure, the request will fail and you will need to call GetIssue to see which issues were not updated.

Parameters:

  • parent (String)

    Required. The parent resource shared by all issues being updated. Format: projects/project/apps/app. If this is set, the parent field in the UpdateIssueRequest messages must either be empty or match this field.

  • batch_update_issues_request_object (Google::Apis::FirebasecrashlyticsV1alpha::BatchUpdateIssuesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



230
231
232
233
234
235
236
237
238
239
240
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 230

def batch_update_issues(parent, batch_update_issues_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/issues:batchUpdate', options)
  command.request_representation = Google::Apis::FirebasecrashlyticsV1alpha::BatchUpdateIssuesRequest::Representation
  command.request_object = batch_update_issues_request_object
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::BatchUpdateIssuesResponse::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::BatchUpdateIssuesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_project_app_issue_note(parent, note_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Note

Create a new note for an issue.

Parameters:

  • parent (String)

    Required. The parent resource where this note will be created. Format: " projects/project/apps/app/issues/issue".

  • note_object (Google::Apis::FirebasecrashlyticsV1alpha::Note) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



333
334
335
336
337
338
339
340
341
342
343
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 333

def create_project_app_issue_note(parent, note_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/notes', options)
  command.request_representation = Google::Apis::FirebasecrashlyticsV1alpha::Note::Representation
  command.request_object = note_object
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::Note::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::Note
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_app_issue_note(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Empty

Delete a note by its name.

Parameters:

  • name (String)

    Required. The name of the note to delete. Format: projects/project/apps/app /issues/issue/notes/note.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



366
367
368
369
370
371
372
373
374
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 366

def delete_project_app_issue_note(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::Empty::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_app_user_crash_reports(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::DeleteUserCrashReportsResponse

Enqueues a request to permanently remove crash reports associated with the specified user. All reports belonging to the specified user will be deleted typically within 24 hours of receiving the crash report.

Parameters:

  • name (String)

    Required. Resource name for user reports, in the format: projects/ PROJECT_IDENTIFIER/apps/APP_ID/users/USER_ID/crashReports - PROJECT_IDENTIFIER: The Firebase project's project number (recommended) or its project ID. Learn more about using project identifiers in Google's AIP 2510 standard. - APP_ID: The globally unique, Firebase-assigned identifier for the Firebase App. This is not your package name or bundle ID. Learn how to find your app ID. - USER_ID: The user ID set using the Crashlytics SDK. Learn how to set user identifiers.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



587
588
589
590
591
592
593
594
595
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 587

def delete_project_app_user_crash_reports(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::DeleteUserCrashReportsResponse::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::DeleteUserCrashReportsResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_app_issue(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Issue

Retrieve an issue.

Parameters:

  • name (String)

    Required. The name of the issue to retrieve. Format: "projects/project/apps/ app/issues/issue".

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



263
264
265
266
267
268
269
270
271
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 263

def get_project_app_issue(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::Issue::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::Issue
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_app_report(name, filter_browser_display_names: nil, filter_device_display_names: nil, filter_device_form_factors: nil, filter_interval_end_time: nil, filter_interval_start_time: nil, filter_issue_content: nil, filter_issue_error_types: nil, filter_issue_id: nil, filter_issue_signals: nil, filter_issue_state: nil, filter_issue_states: nil, filter_issue_variant_id: nil, filter_operating_system_display_names: nil, filter_version_display_names: nil, granularity: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Report

Get a report with its computed results.

Parameters:

  • name (String)

    Required. The report name. Format: "projects/project/apps/app_id/reports/ report".

  • filter_browser_display_names (Array<String>, String) (defaults to: nil)

    Optional. Only count events from the given browser. This string matches Browser.display_name. Format: "name (display_version)" e.g. "Chrome (123)", or just "name" for all possible versions, e.g. simply "Chrome".

  • filter_device_display_names (Array<String>, String) (defaults to: nil)

    Only counts events from the given Device model. This string matches Device. display_name. Format: "manufacturer (model)" e.g. "Google (Pixel 6)", or just " manufacturer" for all possible models, e.g. simply "Google". Note that a device's marketing_name field can not be used for filtering.

  • filter_device_form_factors (Array<String>, String) (defaults to: nil)

    Only counts events from devices with the given form factor (e.g. phone or tablet).

  • filter_interval_end_time (String) (defaults to: nil)

    Optional. Exclusive end of the interval. If specified, a Timestamp matching this interval will have to be before the end.

  • filter_interval_start_time (String) (defaults to: nil)

    Optional. Inclusive start of the interval. If specified, a Timestamp matching this interval will have to be the same or after the start.

  • filter_issue_content (String) (defaults to: nil)

    Optional. A space separated list of filter terms matched against the contents of the issue. Contents include the title and the stack trace. Matches must begin at alphanumeric tokens, i.e., 'util.Sorted' matches 'java.util.SortedSet' but not 'myutil.SortedArray'. The filter matches if all filter terms match. All non-alphanumeric characters are ignored for matching. Filtering is assumed to be prefix-search and order-independent unless phrases are surrounded by "". Any terms contained in quotes are searched using exact-match (given filter term "foo", we will not return "foobar"), and must appear in the order given exactly. To get order-dependence but prefix-search, use a * within the quotes ( "abc foo*" will match "abc foobar", but not "foo abc" "abcd foobar", or "abc xyz foobar").

  • filter_issue_error_types (Array<String>, String) (defaults to: nil)

    Optional. Only counts events of the given error types. This field matches [ Issue.error_type].

  • filter_issue_id (String) (defaults to: nil)

    Optional. Only counts events in the given issue ID. This field matches [Issue. id].

  • filter_issue_signals (Array<String>, String) (defaults to: nil)

    Optional. Only returns issues currently marked with the given signals. This field matches [Issue.signals.signal].

  • filter_issue_state (String) (defaults to: nil)

    Optional. Deprecated: Prefer states field. Only includes events for issues with the given issue state. Only available for topIssues reports.

  • filter_issue_states (Array<String>, String) (defaults to: nil)

    Optional. Only includes events for issues with the given issue states. Only available for topIssues reports.

  • filter_issue_variant_id (String) (defaults to: nil)

    Optional. Only counts events for the given issue variant ID. This field matches [IssueVariant.id].

  • filter_operating_system_display_names (Array<String>, String) (defaults to: nil)

    Only counts events in the given operating system and version. This string matches OperatingSystem.display_name. Format: "osName (osVersion)" e.g. " Android (11)". or just "osName" for all versions, e.g. simply "iPadOS".

  • filter_version_display_names (Array<String>, String) (defaults to: nil)

    Only counts events in the given app version. This string matches Version. display_name. Format: "display_version (build_version)" e.g. "1.2.3 (456)".

  • granularity (String) (defaults to: nil)

    Optional. The report response will contain one data point per time grain. If omitted, the report will contain a single data point for the complete interval.

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of result groups to return. If omitted, defaults to 25.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous call. The page token is only valid for the exact same set of filters, which must also be sent in subsequent requests. This token is valid for 10 minutes after the first request.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 499

def get_project_app_report(name, filter_browser_display_names: nil, filter_device_display_names: nil, filter_device_form_factors: nil, filter_interval_end_time: nil, filter_interval_start_time: nil, filter_issue_content: nil, filter_issue_error_types: nil, filter_issue_id: nil, filter_issue_signals: nil, filter_issue_state: nil, filter_issue_states: nil, filter_issue_variant_id: nil, filter_operating_system_display_names: nil, filter_version_display_names: nil, granularity: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::Report::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::Report
  command.params['name'] = name unless name.nil?
  command.query['filter.browser.displayNames'] = filter_browser_display_names unless filter_browser_display_names.nil?
  command.query['filter.device.displayNames'] = filter_device_display_names unless filter_device_display_names.nil?
  command.query['filter.device.formFactors'] = filter_device_form_factors unless filter_device_form_factors.nil?
  command.query['filter.interval.endTime'] = filter_interval_end_time unless filter_interval_end_time.nil?
  command.query['filter.interval.startTime'] = filter_interval_start_time unless filter_interval_start_time.nil?
  command.query['filter.issue.content'] = filter_issue_content unless filter_issue_content.nil?
  command.query['filter.issue.errorTypes'] = filter_issue_error_types unless filter_issue_error_types.nil?
  command.query['filter.issue.id'] = filter_issue_id unless filter_issue_id.nil?
  command.query['filter.issue.signals'] = filter_issue_signals unless filter_issue_signals.nil?
  command.query['filter.issue.state'] = filter_issue_state unless filter_issue_state.nil?
  command.query['filter.issue.states'] = filter_issue_states unless filter_issue_states.nil?
  command.query['filter.issue.variantId'] = filter_issue_variant_id unless filter_issue_variant_id.nil?
  command.query['filter.operatingSystem.displayNames'] = filter_operating_system_display_names unless filter_operating_system_display_names.nil?
  command.query['filter.version.displayNames'] = filter_version_display_names unless filter_version_display_names.nil?
  command.query['granularity'] = granularity unless granularity.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_app_events(parent, filter_browser_display_names: nil, filter_device_display_names: nil, filter_device_form_factors: nil, filter_interval_end_time: nil, filter_interval_start_time: nil, filter_issue_content: nil, filter_issue_error_types: nil, filter_issue_id: nil, filter_issue_signals: nil, filter_issue_state: nil, filter_issue_states: nil, filter_issue_variant_id: nil, filter_operating_system_display_names: nil, filter_version_display_names: nil, page_size: nil, page_token: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::ListEventsResponse

List the events for an issue matching filter criteria, sorted in descending order by timestamp.

Parameters:

  • parent (String)

    Required. The Firebase application. Format: "projects/project/apps/app_id".

  • filter_browser_display_names (Array<String>, String) (defaults to: nil)

    Optional. Only count events from the given browser. This string matches Browser.display_name. Format: "name (display_version)" e.g. "Chrome (123)", or just "name" for all possible versions, e.g. simply "Chrome".

  • filter_device_display_names (Array<String>, String) (defaults to: nil)

    Only counts events from the given Device model. This string matches Device. display_name. Format: "manufacturer (model)" e.g. "Google (Pixel 6)", or just " manufacturer" for all possible models, e.g. simply "Google". Note that a device's marketing_name field can not be used for filtering.

  • filter_device_form_factors (Array<String>, String) (defaults to: nil)

    Only counts events from devices with the given form factor (e.g. phone or tablet).

  • filter_interval_end_time (String) (defaults to: nil)

    Optional. Exclusive end of the interval. If specified, a Timestamp matching this interval will have to be before the end.

  • filter_interval_start_time (String) (defaults to: nil)

    Optional. Inclusive start of the interval. If specified, a Timestamp matching this interval will have to be the same or after the start.

  • filter_issue_content (String) (defaults to: nil)

    Optional. A space separated list of filter terms matched against the contents of the issue. Contents include the title and the stack trace. Matches must begin at alphanumeric tokens, i.e., 'util.Sorted' matches 'java.util.SortedSet' but not 'myutil.SortedArray'. The filter matches if all filter terms match. All non-alphanumeric characters are ignored for matching. Filtering is assumed to be prefix-search and order-independent unless phrases are surrounded by "". Any terms contained in quotes are searched using exact-match (given filter term "foo", we will not return "foobar"), and must appear in the order given exactly. To get order-dependence but prefix-search, use a * within the quotes ( "abc foo*" will match "abc foobar", but not "foo abc" "abcd foobar", or "abc xyz foobar").

  • filter_issue_error_types (Array<String>, String) (defaults to: nil)

    Optional. Only counts events of the given error types. This field matches [ Issue.error_type].

  • filter_issue_id (String) (defaults to: nil)

    Optional. Only counts events in the given issue ID. This field matches [Issue. id].

  • filter_issue_signals (Array<String>, String) (defaults to: nil)

    Optional. Only returns issues currently marked with the given signals. This field matches [Issue.signals.signal].

  • filter_issue_state (String) (defaults to: nil)

    Optional. Deprecated: Prefer states field. Only includes events for issues with the given issue state. Only available for topIssues reports.

  • filter_issue_states (Array<String>, String) (defaults to: nil)

    Optional. Only includes events for issues with the given issue states. Only available for topIssues reports.

  • filter_issue_variant_id (String) (defaults to: nil)

    Optional. Only counts events for the given issue variant ID. This field matches [IssueVariant.id].

  • filter_operating_system_display_names (Array<String>, String) (defaults to: nil)

    Only counts events in the given operating system and version. This string matches OperatingSystem.display_name. Format: "osName (osVersion)" e.g. " Android (11)". or just "osName" for all versions, e.g. simply "iPadOS".

  • filter_version_display_names (Array<String>, String) (defaults to: nil)

    Only counts events in the given app version. This string matches Version. display_name. Format: "display_version (build_version)" e.g. "1.2.3 (456)".

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of events per page. If omitted, defaults to 10.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous calls.

  • read_mask (String) (defaults to: nil)

    Optional. The list of Event fields to include in the response. If omitted, the full event is returned.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 178

def list_project_app_events(parent, filter_browser_display_names: nil, filter_device_display_names: nil, filter_device_form_factors: nil, filter_interval_end_time: nil, filter_interval_start_time: nil, filter_issue_content: nil, filter_issue_error_types: nil, filter_issue_id: nil, filter_issue_signals: nil, filter_issue_state: nil, filter_issue_states: nil, filter_issue_variant_id: nil, filter_operating_system_display_names: nil, filter_version_display_names: nil, page_size: nil, page_token: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/events', options)
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::ListEventsResponse::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::ListEventsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter.browser.displayNames'] = filter_browser_display_names unless filter_browser_display_names.nil?
  command.query['filter.device.displayNames'] = filter_device_display_names unless filter_device_display_names.nil?
  command.query['filter.device.formFactors'] = filter_device_form_factors unless filter_device_form_factors.nil?
  command.query['filter.interval.endTime'] = filter_interval_end_time unless filter_interval_end_time.nil?
  command.query['filter.interval.startTime'] = filter_interval_start_time unless filter_interval_start_time.nil?
  command.query['filter.issue.content'] = filter_issue_content unless filter_issue_content.nil?
  command.query['filter.issue.errorTypes'] = filter_issue_error_types unless filter_issue_error_types.nil?
  command.query['filter.issue.id'] = filter_issue_id unless filter_issue_id.nil?
  command.query['filter.issue.signals'] = filter_issue_signals unless filter_issue_signals.nil?
  command.query['filter.issue.state'] = filter_issue_state unless filter_issue_state.nil?
  command.query['filter.issue.states'] = filter_issue_states unless filter_issue_states.nil?
  command.query['filter.issue.variantId'] = filter_issue_variant_id unless filter_issue_variant_id.nil?
  command.query['filter.operatingSystem.displayNames'] = filter_operating_system_display_names unless filter_operating_system_display_names.nil?
  command.query['filter.version.displayNames'] = filter_version_display_names unless filter_version_display_names.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['readMask'] = read_mask unless read_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_app_issue_notes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::ListNotesResponse

List all notes for a certain issue, sorted in descending order by timestamp.

Parameters:

  • parent (String)

    Required. The issue the notes belongs to. Format: "projects/project/apps/ app/issues/issue".

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of notes per page. If omitted, defaults to 10.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous calls.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



401
402
403
404
405
406
407
408
409
410
411
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 401

def list_project_app_issue_notes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/notes', options)
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::ListNotesResponse::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::ListNotesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_app_reports(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::ListReportsResponse

List all of the available reports.

Parameters:

  • parent (String)

    Required. The firebase application. Format: "projects/project/apps/app_id".

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



546
547
548
549
550
551
552
553
554
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 546

def list_project_app_reports(parent, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/reports', options)
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::ListReportsResponse::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::ListReportsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_project_app_issue(name, issue_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Issue

Change the state of an issue.

Parameters:

  • name (String)

    Required. Output only. Immutable. Identifier. The name of the issue resource. Format: "projects/project/apps/app/issues/issue".

  • issue_object (Google::Apis::FirebasecrashlyticsV1alpha::Issue) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. The list of Issue fields to update. Currently only "state" is mutable.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/google/apis/firebasecrashlytics_v1alpha/service.rb', line 298

def patch_project_app_issue(name, issue_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1alpha/{+name}', options)
  command.request_representation = Google::Apis::FirebasecrashlyticsV1alpha::Issue::Representation
  command.request_object = issue_object
  command.response_representation = Google::Apis::FirebasecrashlyticsV1alpha::Issue::Representation
  command.response_class = Google::Apis::FirebasecrashlyticsV1alpha::Issue
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end