Class: Google::Apis::FirebasecrashlyticsV1alpha::IntervalMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

A set of computed metric values for a time interval

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntervalMetrics

Returns a new instance of IntervalMetrics.



751
752
753
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

The end of the interval covered by the computation. Corresponds to the JSON property endTime

Returns:

  • (String)


729
730
731
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 729

def end_time
  @end_time
end

#events_countFixnum

The total count of events in the interval. Corresponds to the JSON property eventsCount

Returns:

  • (Fixnum)


734
735
736
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 734

def events_count
  @events_count
end

#impacted_users_countFixnum

The number of distinct users in the set of events. Corresponds to the JSON property impactedUsersCount

Returns:

  • (Fixnum)


739
740
741
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 739

def impacted_users_count
  @impacted_users_count
end

#sessions_countFixnum

The number of distinct sessions in the set of events. Corresponds to the JSON property sessionsCount

Returns:

  • (Fixnum)


744
745
746
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 744

def sessions_count
  @sessions_count
end

#start_timeString

The start of the interval covered by the computation. Corresponds to the JSON property startTime

Returns:

  • (String)


749
750
751
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 749

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



756
757
758
759
760
761
762
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 756

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @events_count = args[:events_count] if args.key?(:events_count)
  @impacted_users_count = args[:impacted_users_count] if args.key?(:impacted_users_count)
  @sessions_count = args[:sessions_count] if args.key?(:sessions_count)
  @start_time = args[:start_time] if args.key?(:start_time)
end