Class: Google::Apis::FirebasecrashlyticsV1alpha::IssueVariant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

A variant is a subgroup of an issue where all events have very similar stack traces. Issues may contain one or more variants.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IssueVariant

Returns a new instance of IssueVariant.



940
941
942
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Immutable. Distinct identifier for the variant. Corresponds to the JSON property id

Returns:

  • (String)


926
927
928
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 926

def id
  @id
end

#sample_eventString

Output only. The resource name for a sample event in this variant. Corresponds to the JSON property sampleEvent

Returns:

  • (String)


931
932
933
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 931

def sample_event
  @sample_event
end

#uriString

Output only. Provides a link to the variant on the Firebase console. When this variant is obtained as part of a Report, then the link will be configured with the same time interval and filters as the request. Corresponds to the JSON property uri

Returns:

  • (String)


938
939
940
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 938

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



945
946
947
948
949
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 945

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @sample_event = args[:sample_event] if args.key?(:sample_event)
  @uri = args[:uri] if args.key?(:uri)
end