Class: Google::Apis::FirebasecrashlyticsV1alpha::ListReportsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

Response method for the ListReports method. The response will always include all of the available reports.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListReportsResponse

Returns a new instance of ListReportsResponse.



1017
1018
1019
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reportsArray<Google::Apis::FirebasecrashlyticsV1alpha::Report>

The report objects returned will contain their names and usage instructions, but include no results. Use the GetReport method to run the report and obtain the paged results. Corresponds to the JSON property reports



1015
1016
1017
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1015

def reports
  @reports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1022
1023
1024
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1022

def update!(**args)
  @reports = args[:reports] if args.key?(:reports)
end