Class: Google::Apis::FirebasecrashlyticsV1alpha::PlayTrack

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

Describes a release track in the Play Developer Console.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlayTrack

Returns a new instance of PlayTrack.



1183
1184
1185
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#titleString

User-generated or auto-generated name of the track. PROD and INTERNAL track types always have auto-generated names, e.g. "prod" and "internal" respectively. Tracks of type EARLY_ACCESS always have a user-generated name. Other track types do not have any guarantees, might have user-generated or auto-generated names. Corresponds to the JSON property title

Returns:

  • (String)


1176
1177
1178
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1176

def title
  @title
end

#typeString

The type of track (prod, internal, etc...). Corresponds to the JSON property type

Returns:

  • (String)


1181
1182
1183
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1181

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1188
1189
1190
1191
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1188

def update!(**args)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end