Class: Google::Apis::FirebasecrashlyticsV1alpha::Thread

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

An application thread.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Thread

Returns a new instance of Thread.



1429
1430
1431
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blamedBoolean Also known as: blamed?

True when the Crashlytics analysis has determined that the stacktrace in this thread is where the fault occurred. Corresponds to the JSON property blamed

Returns:

  • (Boolean)


1362
1363
1364
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1362

def blamed
  @blamed
end

#crash_addressFixnum

The address of the signal that caused the application to crash. Only present on crashed native threads. Corresponds to the JSON property crashAddress

Returns:

  • (Fixnum)


1369
1370
1371
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1369

def crash_address
  @crash_address
end

#crashedBoolean Also known as: crashed?

True when the thread has crashed. Corresponds to the JSON property crashed

Returns:

  • (Boolean)


1374
1375
1376
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1374

def crashed
  @crashed
end

#framesArray<Google::Apis::FirebasecrashlyticsV1alpha::Frame>

The frames in the thread's stacktrace. Corresponds to the JSON property frames



1380
1381
1382
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1380

def frames
  @frames
end

#nameString

The name of the thread. Corresponds to the JSON property name

Returns:

  • (String)


1385
1386
1387
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1385

def name
  @name
end

#queueString

The queue on which the thread was running. Corresponds to the JSON property queue

Returns:

  • (String)


1390
1391
1392
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1390

def queue
  @queue
end

#signalString

The name of the signal that caused the app to crash. Only present on crashed native threads. Corresponds to the JSON property signal

Returns:

  • (String)


1396
1397
1398
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1396

def signal
  @signal
end

#signal_codeString

The code of the signal that caused the app to crash. Only present on crashed native threads. Corresponds to the JSON property signalCode

Returns:

  • (String)


1402
1403
1404
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1402

def signal_code
  @signal_code
end

#subtitleString

The subtitle of the thread. Corresponds to the JSON property subtitle

Returns:

  • (String)


1407
1408
1409
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1407

def subtitle
  @subtitle
end

#sys_thread_idFixnum

The system id of the thread, only available for ANR threads. Corresponds to the JSON property sysThreadId

Returns:

  • (Fixnum)


1412
1413
1414
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1412

def sys_thread_id
  @sys_thread_id
end

#thread_idFixnum

The id of the thread, only available for ANR threads. Corresponds to the JSON property threadId

Returns:

  • (Fixnum)


1417
1418
1419
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1417

def thread_id
  @thread_id
end

#thread_stateString

Output only. The state of the thread at the time the ANR occurred. Corresponds to the JSON property threadState

Returns:

  • (String)


1422
1423
1424
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1422

def thread_state
  @thread_state
end

#titleString

The title of the thread. Corresponds to the JSON property title

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1427

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1434

def update!(**args)
  @blamed = args[:blamed] if args.key?(:blamed)
  @crash_address = args[:crash_address] if args.key?(:crash_address)
  @crashed = args[:crashed] if args.key?(:crashed)
  @frames = args[:frames] if args.key?(:frames)
  @name = args[:name] if args.key?(:name)
  @queue = args[:queue] if args.key?(:queue)
  @signal = args[:signal] if args.key?(:signal)
  @signal_code = args[:signal_code] if args.key?(:signal_code)
  @subtitle = args[:subtitle] if args.key?(:subtitle)
  @sys_thread_id = args[:sys_thread_id] if args.key?(:sys_thread_id)
  @thread_id = args[:thread_id] if args.key?(:thread_id)
  @thread_state = args[:thread_state] if args.key?(:thread_state)
  @title = args[:title] if args.key?(:title)
end