Class: Google::Apis::FirebasecrashlyticsV1alpha::UpdateIssueRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

Request message for the UpdateIssue method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateIssueRequest

Returns a new instance of UpdateIssueRequest.



1469
1470
1471
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#issueGoogle::Apis::FirebasecrashlyticsV1alpha::Issue

An issue describes a set of similar events that have been analyzed by Crashlytics and grouped together. All events within an issue will be of the same error_type: crash, non-fatal exception or ANR. All events within an issue will contain similar stack traces in their blamed thread. Corresponds to the JSON property issue



1461
1462
1463
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1461

def issue
  @issue
end

#update_maskString

Optional. The list of Issue fields to update. Currently only "state" is mutable. Corresponds to the JSON property updateMask

Returns:

  • (String)


1467
1468
1469
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1467

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1474
1475
1476
1477
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1474

def update!(**args)
  @issue = args[:issue] if args.key?(:issue)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end