Class: Google::Apis::FirebasecrashlyticsV1alpha::WebMetricsGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb

Overview

Represents a grouping for metrics specific to web applications.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebMetricsGroup

Returns a new instance of WebMetricsGroup.



1553
1554
1555
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The id of the web metrics group Corresponds to the JSON property id

Returns:

  • (String)


1551
1552
1553
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1551

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1558
1559
1560
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1558

def update!(**args)
  @id = args[:id] if args.key?(:id)
end