Class: Google::Apis::FirebasecrashlyticsV1alpha::Device
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::Device
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
Mobile device metadata.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Device processor architecture.
-
#company_name ⇒ String
An invariant name of the manufacturer that submitted this product in its most recognizable public form, e.g.
-
#display_name ⇒ String
Full device name, suitable for passing to DeviceFilter.
-
#form_factor ⇒ String
See FormFactor message.
-
#manufacturer ⇒ String
Device brand name which is consistent with android.os.Build.BRAND.
-
#marketing_name ⇒ String
Marketing name, most recognizable public form, e.g.
-
#model ⇒ String
The model name which is consistent with android.os.Build.MODEL, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Device
constructor
A new instance of Device.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Device
Returns a new instance of Device.
217 218 219 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Device processor architecture.
Corresponds to the JSON property architecture
182 183 184 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 182 def architecture @architecture end |
#company_name ⇒ String
An invariant name of the manufacturer that submitted this product in its most
recognizable public form, e.g. "Google".
Corresponds to the JSON property companyName
188 189 190 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 188 def company_name @company_name end |
#display_name ⇒ String
Full device name, suitable for passing to DeviceFilter. Format: "manufacturer (
model)".
Corresponds to the JSON property displayName
194 195 196 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 194 def display_name @display_name end |
#form_factor ⇒ String
See FormFactor message.
Corresponds to the JSON property formFactor
199 200 201 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 199 def form_factor @form_factor end |
#manufacturer ⇒ String
Device brand name which is consistent with android.os.Build.BRAND.
Corresponds to the JSON property manufacturer
204 205 206 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 204 def manufacturer @manufacturer end |
#marketing_name ⇒ String
Marketing name, most recognizable public form, e.g. "Pixel 6".
Corresponds to the JSON property marketingName
209 210 211 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 209 def marketing_name @marketing_name end |
#model ⇒ String
The model name which is consistent with android.os.Build.MODEL, e.g. ("SPH-
L710", "GT-I9300").
Corresponds to the JSON property model
215 216 217 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 215 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
222 223 224 225 226 227 228 229 230 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 222 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @company_name = args[:company_name] if args.key?(:company_name) @display_name = args[:display_name] if args.key?(:display_name) @form_factor = args[:form_factor] if args.key?(:form_factor) @manufacturer = args[:manufacturer] if args.key?(:manufacturer) @marketing_name = args[:marketing_name] if args.key?(:marketing_name) @model = args[:model] if args.key?(:model) end |