Class: Google::Apis::FirebasecrashlyticsV1alpha::Error
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::Error
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
A non-fatal error and its stacktrace, only from Apple apps.
Instance Attribute Summary collapse
-
#blamed ⇒ Boolean
(also: #blamed?)
True when the Crashlytics analysis has determined that the stacktrace in this error is where the fault occurred.
-
#code ⇒ Fixnum
Error code associated with the app's custom logged NSError.
-
#frames ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Frame>
The frames in the error's stacktrace.
-
#queue ⇒ String
The queue on which the thread was running.
-
#subtitle ⇒ String
The subtitle of the error.
-
#title ⇒ String
The title of the error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
285 286 287 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blamed ⇒ Boolean Also known as: blamed?
True when the Crashlytics analysis has determined that the stacktrace in this
error is where the fault occurred.
Corresponds to the JSON property blamed
257 258 259 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 257 def blamed @blamed end |
#code ⇒ Fixnum
Error code associated with the app's custom logged NSError.
Corresponds to the JSON property code
263 264 265 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 263 def code @code end |
#frames ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Frame>
The frames in the error's stacktrace.
Corresponds to the JSON property frames
268 269 270 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 268 def frames @frames end |
#queue ⇒ String
The queue on which the thread was running.
Corresponds to the JSON property queue
273 274 275 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 273 def queue @queue end |
#subtitle ⇒ String
The subtitle of the error.
Corresponds to the JSON property subtitle
278 279 280 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 278 def subtitle @subtitle end |
#title ⇒ String
The title of the error.
Corresponds to the JSON property title
283 284 285 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 283 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
290 291 292 293 294 295 296 297 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 290 def update!(**args) @blamed = args[:blamed] if args.key?(:blamed) @code = args[:code] if args.key?(:code) @frames = args[:frames] if args.key?(:frames) @queue = args[:queue] if args.key?(:queue) @subtitle = args[:subtitle] if args.key?(:subtitle) @title = args[:title] if args.key?(:title) end |