Class: Google::Apis::FirebasecrashlyticsV1alpha::Event
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::Event
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
The message describing a single Crashlytics event. Related to BigQuery export schema, which can be found at Export Crashlytics data to BigQuery
Instance Attribute Summary collapse
-
#app_orientation ⇒ String
App orientation at the time of the crash (portrait or landscape).
-
#blame_frame ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Frame
A frame in a stacktrace.
-
#breadcrumbs ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Breadcrumb>
Analytics events recorded by the analytics SDK during the session.
-
#browser ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Browser
Web browser metadata.
-
#build_stamp ⇒ String
Metadata provided by the app's build system, including version control repository info.
-
#bundle_or_package ⇒ String
The bundle name for iOS apps or the package name of Android apps.
-
#crashlytics_sdk_version ⇒ String
Crashlytics SDK version.
-
#custom_keys ⇒ Hash<String,String>
Custom keys set by the developer during the session.
-
#device ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Device
Mobile device metadata.
-
#device_orientation ⇒ String
Device orientation at the time of the crash (portrait or landscape).
-
#errors ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Error>
Apple only.
-
#event_id ⇒ String
Output only.
-
#event_time ⇒ String
Device timestamp that the event was recorded.
-
#exceptions ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Exception>
Android and web only.
-
#installation_uuid ⇒ String
Unique identifier for the device-app installation.
-
#issue ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Issue
An issue describes a set of similar events that have been analyzed by Crashlytics and grouped together.
-
#issue_subtitle ⇒ String
The subtitle of the issue in which the event was grouped.
-
#issue_title ⇒ String
The title of the issue in which the event was grouped.
-
#issue_variant ⇒ Google::Apis::FirebasecrashlyticsV1alpha::IssueVariant
A variant is a subgroup of an issue where all events have very similar stack traces.
-
#logs ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Log>
Log messages recorded by the developer during the session.
-
#memory ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Memory
Mobile device memory usage.
-
#name ⇒ String
Required.
-
#operating_system ⇒ Google::Apis::FirebasecrashlyticsV1alpha::OperatingSystem
Mobile device operating system metadata.
-
#platform ⇒ String
ANDROID, IOS, or WEB.
-
#process_state ⇒ String
The state of the app process at the time of the event.
-
#received_time ⇒ String
Server timestamp that the event was received by Crashlytics.
-
#route_path ⇒ String
Output only.
-
#session_id ⇒ String
Unique identifier for the Firebase session.
-
#storage ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Storage
Mobile device disk/flash usage.
-
#threads ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Thread>
Application threads present at the time the event was recorded.
-
#user ⇒ Google::Apis::FirebasecrashlyticsV1alpha::User
Developer-provided end user identifiers.
-
#version ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Version
Application software version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Event
constructor
A new instance of Event.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Event
Returns a new instance of Event.
482 483 484 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_orientation ⇒ String
App orientation at the time of the crash (portrait or landscape).
Corresponds to the JSON property appOrientation
310 311 312 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 310 def app_orientation @app_orientation end |
#blame_frame ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Frame
A frame in a stacktrace.
Corresponds to the JSON property blameFrame
315 316 317 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 315 def blame_frame @blame_frame end |
#breadcrumbs ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Breadcrumb>
Analytics events recorded by the analytics SDK during the session.
Corresponds to the JSON property breadcrumbs
320 321 322 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 320 def @breadcrumbs end |
#browser ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Browser
Web browser metadata.
Corresponds to the JSON property browser
325 326 327 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 325 def browser @browser end |
#build_stamp ⇒ String
Metadata provided by the app's build system, including version control
repository info.
Corresponds to the JSON property buildStamp
331 332 333 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 331 def build_stamp @build_stamp end |
#bundle_or_package ⇒ String
The bundle name for iOS apps or the package name of Android apps. Format: "com.
mycompany.myapp".
Corresponds to the JSON property bundleOrPackage
337 338 339 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 337 def bundle_or_package @bundle_or_package end |
#crashlytics_sdk_version ⇒ String
Crashlytics SDK version.
Corresponds to the JSON property crashlyticsSdkVersion
342 343 344 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 342 def crashlytics_sdk_version @crashlytics_sdk_version end |
#custom_keys ⇒ Hash<String,String>
Custom keys set by the developer during the session.
Corresponds to the JSON property customKeys
347 348 349 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 347 def custom_keys @custom_keys end |
#device ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Device
Mobile device metadata.
Corresponds to the JSON property device
352 353 354 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 352 def device @device end |
#device_orientation ⇒ String
Device orientation at the time of the crash (portrait or landscape).
Corresponds to the JSON property deviceOrientation
357 358 359 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 357 def device_orientation @device_orientation end |
#errors ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Error>
Apple only. A non-fatal error captured by the iOS SDK and its stacktrace.
Corresponds to the JSON property errors
362 363 364 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 362 def errors @errors end |
#event_id ⇒ String
Output only. Immutable. The unique event identifier is assigned during
processing.
Corresponds to the JSON property eventId
368 369 370 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 368 def event_id @event_id end |
#event_time ⇒ String
Device timestamp that the event was recorded.
Corresponds to the JSON property eventTime
373 374 375 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 373 def event_time @event_time end |
#exceptions ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Exception>
Android and web only. Exceptions that occurred during this event. Nested
exceptions are presented in reverse chronological order, so that the last
record is the first exception thrown.
Corresponds to the JSON property exceptions
380 381 382 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 380 def exceptions @exceptions end |
#installation_uuid ⇒ String
Unique identifier for the device-app installation. This field is used to
compute the unique number of impacted users.
Corresponds to the JSON property installationUuid
386 387 388 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 386 def installation_uuid @installation_uuid end |
#issue ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Issue
An issue describes a set of similar events that have been analyzed by
Crashlytics and grouped together. All events within an issue will be of the
same error_type: crash, non-fatal exception or ANR. All events within an issue
will contain similar stack traces in their blamed thread.
Corresponds to the JSON property issue
394 395 396 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 394 def issue @issue end |
#issue_subtitle ⇒ String
The subtitle of the issue in which the event was grouped. This is usually a
symbol or an exception message.
Corresponds to the JSON property issueSubtitle
400 401 402 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 400 def issue_subtitle @issue_subtitle end |
#issue_title ⇒ String
The title of the issue in which the event was grouped. This is usually a
source file or method name.
Corresponds to the JSON property issueTitle
406 407 408 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 406 def issue_title @issue_title end |
#issue_variant ⇒ Google::Apis::FirebasecrashlyticsV1alpha::IssueVariant
A variant is a subgroup of an issue where all events have very similar stack
traces. Issues may contain one or more variants.
Corresponds to the JSON property issueVariant
412 413 414 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 412 def issue_variant @issue_variant end |
#logs ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Log>
Log messages recorded by the developer during the session.
Corresponds to the JSON property logs
417 418 419 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 417 def logs @logs end |
#memory ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Memory
Mobile device memory usage.
Corresponds to the JSON property memory
422 423 424 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 422 def memory @memory end |
#name ⇒ String
Required. Output only. Immutable. Identifier. The name of the event resource.
Format: "projects/project/apps/app_id/events/event".
Corresponds to the JSON property name
428 429 430 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 428 def name @name end |
#operating_system ⇒ Google::Apis::FirebasecrashlyticsV1alpha::OperatingSystem
Mobile device operating system metadata.
Corresponds to the JSON property operatingSystem
433 434 435 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 433 def @operating_system end |
#platform ⇒ String
ANDROID, IOS, or WEB.
Corresponds to the JSON property platform
438 439 440 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 438 def platform @platform end |
#process_state ⇒ String
The state of the app process at the time of the event.
Corresponds to the JSON property processState
443 444 445 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 443 def process_state @process_state end |
#received_time ⇒ String
Server timestamp that the event was received by Crashlytics.
Corresponds to the JSON property receivedTime
448 449 450 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 448 def received_time @received_time end |
#route_path ⇒ String
Output only. Web only. The route path of the web application when the event
occurred, excluding query parameters and fragment.
Corresponds to the JSON property routePath
454 455 456 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 454 def route_path @route_path end |
#session_id ⇒ String
Unique identifier for the Firebase session.
Corresponds to the JSON property sessionId
459 460 461 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 459 def session_id @session_id end |
#storage ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Storage
Mobile device disk/flash usage. Not reported for all devices.
Corresponds to the JSON property storage
464 465 466 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 464 def storage @storage end |
#threads ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Thread>
Application threads present at the time the event was recorded. Each contains
a stacktrace. One thread will be blamed for the error.
Corresponds to the JSON property threads
470 471 472 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 470 def threads @threads end |
#user ⇒ Google::Apis::FirebasecrashlyticsV1alpha::User
Developer-provided end user identifiers.
Corresponds to the JSON property user
475 476 477 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 475 def user @user end |
#version ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Version
Application software version.
Corresponds to the JSON property version
480 481 482 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 480 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 487 def update!(**args) @app_orientation = args[:app_orientation] if args.key?(:app_orientation) @blame_frame = args[:blame_frame] if args.key?(:blame_frame) @breadcrumbs = args[:breadcrumbs] if args.key?(:breadcrumbs) @browser = args[:browser] if args.key?(:browser) @build_stamp = args[:build_stamp] if args.key?(:build_stamp) @bundle_or_package = args[:bundle_or_package] if args.key?(:bundle_or_package) @crashlytics_sdk_version = args[:crashlytics_sdk_version] if args.key?(:crashlytics_sdk_version) @custom_keys = args[:custom_keys] if args.key?(:custom_keys) @device = args[:device] if args.key?(:device) @device_orientation = args[:device_orientation] if args.key?(:device_orientation) @errors = args[:errors] if args.key?(:errors) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) @exceptions = args[:exceptions] if args.key?(:exceptions) @installation_uuid = args[:installation_uuid] if args.key?(:installation_uuid) @issue = args[:issue] if args.key?(:issue) @issue_subtitle = args[:issue_subtitle] if args.key?(:issue_subtitle) @issue_title = args[:issue_title] if args.key?(:issue_title) @issue_variant = args[:issue_variant] if args.key?(:issue_variant) @logs = args[:logs] if args.key?(:logs) @memory = args[:memory] if args.key?(:memory) @name = args[:name] if args.key?(:name) @operating_system = args[:operating_system] if args.key?(:operating_system) @platform = args[:platform] if args.key?(:platform) @process_state = args[:process_state] if args.key?(:process_state) @received_time = args[:received_time] if args.key?(:received_time) @route_path = args[:route_path] if args.key?(:route_path) @session_id = args[:session_id] if args.key?(:session_id) @storage = args[:storage] if args.key?(:storage) @threads = args[:threads] if args.key?(:threads) @user = args[:user] if args.key?(:user) @version = args[:version] if args.key?(:version) end |