Class: Google::Apis::FirebasecrashlyticsV1alpha::FirebaseSessionEvent
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::FirebaseSessionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
Sessions recorded by the Firebase App Quality Sessions SDK.
Instance Attribute Summary collapse
-
#device ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Device
Mobile device metadata.
-
#event_time ⇒ String
The start timestamp for the session event.
-
#event_type ⇒ String
Session event type.
-
#firebase_installation_id ⇒ String
Uniquely identifies a device with Firebase apps installed.
-
#first_session_id ⇒ String
The identifier of the first session since the last cold start.
-
#operating_system ⇒ Google::Apis::FirebasecrashlyticsV1alpha::OperatingSystem
Mobile device operating system metadata.
-
#session_id ⇒ String
Unique identifier for the Firebase session.
-
#session_index ⇒ Fixnum
Indicates the number of sessions since the last cold start.
-
#version ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Version
Application software version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirebaseSessionEvent
constructor
A new instance of FirebaseSessionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirebaseSessionEvent
Returns a new instance of FirebaseSessionEvent.
632 633 634 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 632 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Device
Mobile device metadata.
Corresponds to the JSON property device
589 590 591 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 589 def device @device end |
#event_time ⇒ String
The start timestamp for the session event.
Corresponds to the JSON property eventTime
594 595 596 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 594 def event_time @event_time end |
#event_type ⇒ String
Session event type. The SDK only supports SESSION_START events at this time.
Corresponds to the JSON property eventType
599 600 601 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 599 def event_type @event_type end |
#firebase_installation_id ⇒ String
Uniquely identifies a device with Firebase apps installed.
Corresponds to the JSON property firebaseInstallationId
604 605 606 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 604 def firebase_installation_id @firebase_installation_id end |
#first_session_id ⇒ String
The identifier of the first session since the last cold start. This id and the
session_id will be the same for app launches.
Corresponds to the JSON property firstSessionId
610 611 612 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 610 def first_session_id @first_session_id end |
#operating_system ⇒ Google::Apis::FirebasecrashlyticsV1alpha::OperatingSystem
Mobile device operating system metadata.
Corresponds to the JSON property operatingSystem
615 616 617 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 615 def @operating_system end |
#session_id ⇒ String
Unique identifier for the Firebase session.
Corresponds to the JSON property sessionId
620 621 622 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 620 def session_id @session_id end |
#session_index ⇒ Fixnum
Indicates the number of sessions since the last cold start.
Corresponds to the JSON property sessionIndex
625 626 627 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 625 def session_index @session_index end |
#version ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Version
Application software version.
Corresponds to the JSON property version
630 631 632 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 630 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
637 638 639 640 641 642 643 644 645 646 647 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 637 def update!(**args) @device = args[:device] if args.key?(:device) @event_time = args[:event_time] if args.key?(:event_time) @event_type = args[:event_type] if args.key?(:event_type) @firebase_installation_id = args[:firebase_installation_id] if args.key?(:firebase_installation_id) @first_session_id = args[:first_session_id] if args.key?(:first_session_id) @operating_system = args[:operating_system] if args.key?(:operating_system) @session_id = args[:session_id] if args.key?(:session_id) @session_index = args[:session_index] if args.key?(:session_index) @version = args[:version] if args.key?(:version) end |