Class: Google::Apis::FirebasecrashlyticsV1alpha::Frame
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::Frame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
A frame in a stacktrace.
Instance Attribute Summary collapse
-
#address ⇒ Fixnum
The address in the binary image which contains the code.
-
#blamed ⇒ Boolean
(also: #blamed?)
True when the Crashlytics analysis has determined that this frame is likely to be the cause of the error.
-
#column ⇒ Fixnum
The column on the line.
-
#file ⇒ String
The name of the source file in which the frame is found.
-
#library ⇒ String
The display name of the library that includes the frame.
-
#line ⇒ Fixnum
The line number in the file of the frame.
-
#offset ⇒ Fixnum
The byte offset into the binary image that contains the code.
-
#owner ⇒ String
One of DEVELOPER, VENDOR, RUNTIME, PLATFORM, or SYSTEM.
-
#symbol ⇒ String
The frame symbol after it has been deobfuscated or symbolicated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Frame
constructor
A new instance of Frame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Frame
Returns a new instance of Frame.
704 705 706 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 704 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Fixnum
The address in the binary image which contains the code. Present for native
frames.
Corresponds to the JSON property address
658 659 660 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 658 def address @address end |
#blamed ⇒ Boolean Also known as: blamed?
True when the Crashlytics analysis has determined that this frame is likely to
be the cause of the error.
Corresponds to the JSON property blamed
664 665 666 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 664 def blamed @blamed end |
#column ⇒ Fixnum
The column on the line.
Corresponds to the JSON property column
670 671 672 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 670 def column @column end |
#file ⇒ String
The name of the source file in which the frame is found.
Corresponds to the JSON property file
675 676 677 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 675 def file @file end |
#library ⇒ String
The display name of the library that includes the frame.
Corresponds to the JSON property library
680 681 682 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 680 def library @library end |
#line ⇒ Fixnum
The line number in the file of the frame.
Corresponds to the JSON property line
685 686 687 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 685 def line @line end |
#offset ⇒ Fixnum
The byte offset into the binary image that contains the code. Present for
native frames.
Corresponds to the JSON property offset
691 692 693 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 691 def offset @offset end |
#owner ⇒ String
One of DEVELOPER, VENDOR, RUNTIME, PLATFORM, or SYSTEM.
Corresponds to the JSON property owner
696 697 698 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 696 def owner @owner end |
#symbol ⇒ String
The frame symbol after it has been deobfuscated or symbolicated. The raw
symbol from the device if it could not be hydrated.
Corresponds to the JSON property symbol
702 703 704 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 702 def symbol @symbol end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
709 710 711 712 713 714 715 716 717 718 719 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 709 def update!(**args) @address = args[:address] if args.key?(:address) @blamed = args[:blamed] if args.key?(:blamed) @column = args[:column] if args.key?(:column) @file = args[:file] if args.key?(:file) @library = args[:library] if args.key?(:library) @line = args[:line] if args.key?(:line) @offset = args[:offset] if args.key?(:offset) @owner = args[:owner] if args.key?(:owner) @symbol = args[:symbol] if args.key?(:symbol) end |