Class: Google::Apis::FirebasecrashlyticsV1alpha::IntervalMetrics
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::IntervalMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
A set of computed metric values for a time interval
Instance Attribute Summary collapse
-
#end_time ⇒ String
The end of the interval covered by the computation.
-
#events_count ⇒ Fixnum
The total count of events in the interval.
-
#impacted_users_count ⇒ Fixnum
The number of distinct users in the set of events.
-
#sessions_count ⇒ Fixnum
The number of distinct sessions in the set of events.
-
#start_time ⇒ String
The start of the interval covered by the computation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntervalMetrics
constructor
A new instance of IntervalMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntervalMetrics
Returns a new instance of IntervalMetrics.
751 752 753 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The end of the interval covered by the computation.
Corresponds to the JSON property endTime
729 730 731 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 729 def end_time @end_time end |
#events_count ⇒ Fixnum
The total count of events in the interval.
Corresponds to the JSON property eventsCount
734 735 736 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 734 def events_count @events_count end |
#impacted_users_count ⇒ Fixnum
The number of distinct users in the set of events.
Corresponds to the JSON property impactedUsersCount
739 740 741 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 739 def impacted_users_count @impacted_users_count end |
#sessions_count ⇒ Fixnum
The number of distinct sessions in the set of events.
Corresponds to the JSON property sessionsCount
744 745 746 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 744 def sessions_count @sessions_count end |
#start_time ⇒ String
The start of the interval covered by the computation.
Corresponds to the JSON property startTime
749 750 751 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 749 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
756 757 758 759 760 761 762 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 756 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @events_count = args[:events_count] if args.key?(:events_count) @impacted_users_count = args[:impacted_users_count] if args.key?(:impacted_users_count) @sessions_count = args[:sessions_count] if args.key?(:sessions_count) @start_time = args[:start_time] if args.key?(:start_time) end |