Class: Google::Apis::FirebasecrashlyticsV1alpha::Issue
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
An issue describes a set of similar events that have been analyzed by Crashlytics and grouped together. All events within an issue will be of the same error_type: crash, non-fatal exception or ANR. All events within an issue will contain similar stack traces in their blamed thread.
Instance Attribute Summary collapse
-
#error_type ⇒ String
Output only.
-
#first_seen_time ⇒ String
Output only.
-
#first_seen_version ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#last_seen_time ⇒ String
Output only.
-
#last_seen_version ⇒ String
Output only.
-
#name ⇒ String
Required.
-
#notes_count ⇒ Fixnum
Output only.
-
#sample_event ⇒ String
Output only.
-
#signals ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::IssueSignals>
Output only.
-
#state ⇒ String
Output only.
-
#state_update_time ⇒ String
Output only.
-
#subtitle ⇒ String
Output only.
-
#title ⇒ String
Output only.
-
#uri ⇒ String
Output only.
-
#variants ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::IssueVariant>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Issue
constructor
A new instance of Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Issue
Returns a new instance of Issue.
868 869 870 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_type ⇒ String
Output only. Immutable. Indicates whether this issue is a crash, non-fatal
exception, or ANR.
Corresponds to the JSON property errorType
776 777 778 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 776 def error_type @error_type end |
#first_seen_time ⇒ String
Output only. Immutable. The first time this issue was seen.
Corresponds to the JSON property firstSeenTime
781 782 783 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 781 def first_seen_time @first_seen_time end |
#first_seen_version ⇒ String
Output only. Immutable. The first app display_version in which this issue was
seen, populated for mobile issues only.
Corresponds to the JSON property firstSeenVersion
787 788 789 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 787 def first_seen_version @first_seen_version end |
#id ⇒ String
Output only. Immutable. Unique identifier for the issue.
Corresponds to the JSON property id
792 793 794 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 792 def id @id end |
#last_seen_time ⇒ String
Output only. The most recent time this issue was seen.
Corresponds to the JSON property lastSeenTime
797 798 799 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 797 def last_seen_time @last_seen_time end |
#last_seen_version ⇒ String
Output only. The most recent app display_version in which this issue was seen,
populated for mobile issues only.
Corresponds to the JSON property lastSeenVersion
803 804 805 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 803 def last_seen_version @last_seen_version end |
#name ⇒ String
Required. Output only. Immutable. Identifier. The name of the issue resource.
Format: "projects/project/apps/app/issues/issue".
Corresponds to the JSON property name
809 810 811 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 809 def name @name end |
#notes_count ⇒ Fixnum
Output only. The number of notes attached to an issue.
Corresponds to the JSON property notesCount
814 815 816 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 814 def notes_count @notes_count end |
#sample_event ⇒ String
Output only. The resource name for a sample event in this issue.
Corresponds to the JSON property sampleEvent
819 820 821 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 819 def sample_event @sample_event end |
#signals ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::IssueSignals>
Output only. Immutable. Distinctive characteristics assigned by the
Crashlytics analyzer.
Corresponds to the JSON property signals
825 826 827 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 825 def signals @signals end |
#state ⇒ String
Output only. Indicates whether this issue is open, closed or muted. For
details on how issue states change without user actions, see Regressed Issues.
Corresponds to the JSON property state
833 834 835 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 833 def state @state end |
#state_update_time ⇒ String
Output only. The time at which the issue state was last changed.
Corresponds to the JSON property stateUpdateTime
838 839 840 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 838 def state_update_time @state_update_time end |
#subtitle ⇒ String
Output only. Immutable. Caption subtitle. This is usually a symbol or an
exception message.
Corresponds to the JSON property subtitle
844 845 846 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 844 def subtitle @subtitle end |
#title ⇒ String
Output only. Immutable. Caption title. This is usually a source file or method
name.
Corresponds to the JSON property title
850 851 852 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 850 def title @title end |
#uri ⇒ String
Output only. Provides a link to the Issue on the Firebase console. When this
Issue is obtained as part of a Report, then the link will be configured with
the same time interval and filters as the request.
Corresponds to the JSON property uri
857 858 859 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 857 def uri @uri end |
#variants ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::IssueVariant>
Output only. Immutable. The top 12 variants (subgroups) within the issue.
Variants group events within an issue that are very similar. A single result
implies that the variant is the same as the parent issue. This field will be
empty when multiple issues are requested. Request a single issue to list
variants.
Corresponds to the JSON property variants
866 867 868 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 866 def variants @variants end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 873 def update!(**args) @error_type = args[:error_type] if args.key?(:error_type) @first_seen_time = args[:first_seen_time] if args.key?(:first_seen_time) @first_seen_version = args[:first_seen_version] if args.key?(:first_seen_version) @id = args[:id] if args.key?(:id) @last_seen_time = args[:last_seen_time] if args.key?(:last_seen_time) @last_seen_version = args[:last_seen_version] if args.key?(:last_seen_version) @name = args[:name] if args.key?(:name) @notes_count = args[:notes_count] if args.key?(:notes_count) @sample_event = args[:sample_event] if args.key?(:sample_event) @signals = args[:signals] if args.key?(:signals) @state = args[:state] if args.key?(:state) @state_update_time = args[:state_update_time] if args.key?(:state_update_time) @subtitle = args[:subtitle] if args.key?(:subtitle) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) @variants = args[:variants] if args.key?(:variants) end |