Class: Google::Apis::FirebasecrashlyticsV1alpha::ListNotesResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::ListNotesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
Response message for the ListNotes method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A pagination token to retrieve the next page of notes.
-
#notes ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Note>
Returns notes ordered descending by the timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListNotesResponse
constructor
A new instance of ListNotesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListNotesResponse
Returns a new instance of ListNotesResponse.
994 995 996 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A pagination token to retrieve the next page of notes. If this field is not
present, there are no subsequent notes.
Corresponds to the JSON property nextPageToken
987 988 989 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 987 def next_page_token @next_page_token end |
#notes ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::Note>
Returns notes ordered descending by the timestamp.
Corresponds to the JSON property notes
992 993 994 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 992 def notes @notes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
999 1000 1001 1002 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 999 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @notes = args[:notes] if args.key?(:notes) end |