Class: Google::Apis::FirebasecrashlyticsV1alpha::PlayTrack
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::PlayTrack
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
Describes a release track in the Play Developer Console.
Instance Attribute Summary collapse
-
#title ⇒ String
User-generated or auto-generated name of the track.
-
#type ⇒ String
The type of track (prod, internal, etc...).
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlayTrack
constructor
A new instance of PlayTrack.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlayTrack
Returns a new instance of PlayTrack.
1183 1184 1185 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#title ⇒ String
User-generated or auto-generated name of the track. PROD and INTERNAL track
types always have auto-generated names, e.g. "prod" and "internal"
respectively. Tracks of type EARLY_ACCESS always have a user-generated name.
Other track types do not have any guarantees, might have user-generated or
auto-generated names.
Corresponds to the JSON property title
1176 1177 1178 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1176 def title @title end |
#type ⇒ String
The type of track (prod, internal, etc...).
Corresponds to the JSON property type
1181 1182 1183 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1181 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1188 1189 1190 1191 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1188 def update!(**args) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |