Class: Google::Apis::FirebasecrashlyticsV1alpha::Report
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::Report
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
Response message for the GetReport method. A report consists of the results of a query over an application's events. The events may be filtered by various criteria defined in the filters proto. The result will consist of a number of paginated groups, of a type relevant to the report such as issues or device models.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#groups ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::ReportGroup>
Aggregate event statistics in the report will be grouped by a dimension, such as by issue or by version.
-
#name ⇒ String
The name of the report.
-
#next_page_token ⇒ String
Output only.
-
#total_size ⇒ Fixnum
Output only.
-
#usage ⇒ String
Usage instructions for the report with a description of the result metrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Report
constructor
A new instance of Report.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Report
Returns a new instance of Report.
1240 1241 1242 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1240 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The displayable title of the report.
Corresponds to the JSON property displayName
1205 1206 1207 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1205 def display_name @display_name end |
#groups ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::ReportGroup>
Aggregate event statistics in the report will be grouped by a dimension, such
as by issue or by version. The response contains one element per group, and
all ReportGroup messages will have the same parent field.
Corresponds to the JSON property groups
1212 1213 1214 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1212 def groups @groups end |
#name ⇒ String
The name of the report. Format: "projects/project/apps/app_id/reports/
report".
Corresponds to the JSON property name
1218 1219 1220 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1218 def name @name end |
#next_page_token ⇒ String
Output only. A page token used to retrieve additional report groups. If this
field is not present, there are no subsequent pages available to retrieve.
Corresponds to the JSON property nextPageToken
1224 1225 1226 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1224 def next_page_token @next_page_token end |
#total_size ⇒ Fixnum
Output only. The total number of groups retrievable by the request.
Corresponds to the JSON property totalSize
1229 1230 1231 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1229 def total_size @total_size end |
#usage ⇒ String
Usage instructions for the report with a description of the result metrics.
This field contains a description of the underlying query and describes the
expected response data with any known caveats. This string can be displayed in
the UI of any integration that offers comprehensive access to all Crashlytics
reports.
Corresponds to the JSON property usage
1238 1239 1240 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1238 def usage @usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1245 1246 1247 1248 1249 1250 1251 1252 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1245 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @groups = args[:groups] if args.key?(:groups) @name = args[:name] if args.key?(:name) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @total_size = args[:total_size] if args.key?(:total_size) @usage = args[:usage] if args.key?(:usage) end |