Class: Google::Apis::FirebasecrashlyticsV1alpha::ReportGroup
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::ReportGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
A group of results in an EventReport. In any report, the group_parent field is strictly the same type for all of the groups in any collection.
Instance Attribute Summary collapse
-
#browser ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Browser
Web browser metadata.
-
#device ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Device
Mobile device metadata.
-
#issue ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Issue
An issue describes a set of similar events that have been analyzed by Crashlytics and grouped together.
-
#metrics ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::IntervalMetrics>
Scalar metrics will contain a single object covering the entire interval, while time-dimensioned graphs will contain one per time grain.
-
#operating_system ⇒ Google::Apis::FirebasecrashlyticsV1alpha::OperatingSystem
Mobile device operating system metadata.
-
#subgroups ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::ReportGroup>
When applicable, this field contains additional nested groupings.
-
#variant ⇒ Google::Apis::FirebasecrashlyticsV1alpha::IssueVariant
A variant is a subgroup of an issue where all events have very similar stack traces.
-
#version ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Version
Application software version.
-
#web_metrics_group ⇒ Google::Apis::FirebasecrashlyticsV1alpha::WebMetricsGroup
Represents a grouping for metrics specific to web applications.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportGroup
constructor
A new instance of ReportGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportGroup
Returns a new instance of ReportGroup.
1311 1312 1313 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#browser ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Browser
Web browser metadata.
Corresponds to the JSON property browser
1263 1264 1265 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1263 def browser @browser end |
#device ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Device
Mobile device metadata.
Corresponds to the JSON property device
1268 1269 1270 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1268 def device @device end |
#issue ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Issue
An issue describes a set of similar events that have been analyzed by
Crashlytics and grouped together. All events within an issue will be of the
same error_type: crash, non-fatal exception or ANR. All events within an issue
will contain similar stack traces in their blamed thread.
Corresponds to the JSON property issue
1276 1277 1278 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1276 def issue @issue end |
#metrics ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::IntervalMetrics>
Scalar metrics will contain a single object covering the entire interval,
while time-dimensioned graphs will contain one per time grain.
Corresponds to the JSON property metrics
1282 1283 1284 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1282 def metrics @metrics end |
#operating_system ⇒ Google::Apis::FirebasecrashlyticsV1alpha::OperatingSystem
Mobile device operating system metadata.
Corresponds to the JSON property operatingSystem
1287 1288 1289 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1287 def @operating_system end |
#subgroups ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::ReportGroup>
When applicable, this field contains additional nested groupings. For example,
events can be grouped by operating system and by operating system version.
Corresponds to the JSON property subgroups
1293 1294 1295 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1293 def subgroups @subgroups end |
#variant ⇒ Google::Apis::FirebasecrashlyticsV1alpha::IssueVariant
A variant is a subgroup of an issue where all events have very similar stack
traces. Issues may contain one or more variants.
Corresponds to the JSON property variant
1299 1300 1301 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1299 def variant @variant end |
#version ⇒ Google::Apis::FirebasecrashlyticsV1alpha::Version
Application software version.
Corresponds to the JSON property version
1304 1305 1306 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1304 def version @version end |
#web_metrics_group ⇒ Google::Apis::FirebasecrashlyticsV1alpha::WebMetricsGroup
Represents a grouping for metrics specific to web applications.
Corresponds to the JSON property webMetricsGroup
1309 1310 1311 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1309 def web_metrics_group @web_metrics_group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1316 def update!(**args) @browser = args[:browser] if args.key?(:browser) @device = args[:device] if args.key?(:device) @issue = args[:issue] if args.key?(:issue) @metrics = args[:metrics] if args.key?(:metrics) @operating_system = args[:operating_system] if args.key?(:operating_system) @subgroups = args[:subgroups] if args.key?(:subgroups) @variant = args[:variant] if args.key?(:variant) @version = args[:version] if args.key?(:version) @web_metrics_group = args[:web_metrics_group] if args.key?(:web_metrics_group) end |