Class: Google::Apis::FirebasecrashlyticsV1alpha::Version
- Inherits:
-
Object
- Object
- Google::Apis::FirebasecrashlyticsV1alpha::Version
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasecrashlytics_v1alpha/classes.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb,
lib/google/apis/firebasecrashlytics_v1alpha/representations.rb
Overview
Application software version.
Instance Attribute Summary collapse
-
#build_version ⇒ String
Mobile only.
-
#display_name ⇒ String
Compound readable string containing both display and build versions.
-
#display_version ⇒ String
Readable version string, e.g.
-
#tracks ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::PlayTrack>
Indicates releases which have artifacts that are currently available in the Play Store to the target audience of the track.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Version
constructor
A new instance of Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Version
Returns a new instance of Version.
1531 1532 1533 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build_version ⇒ String
Mobile only. One display_version can have many build_version. On Android,
strictly the same as "version code". On iOS, strictly the same as "build
number" or CFBundleVersion.
Corresponds to the JSON property buildVersion
1508 1509 1510 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1508 def build_version @build_version end |
#display_name ⇒ String
Compound readable string containing both display and build versions. Format: "
display_version (build_version)" e.g. "1.2.3 (456)". This string can be used
for filtering with the VersionFilter.display_name field.
Corresponds to the JSON property displayName
1515 1516 1517 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1515 def display_name @display_name end |
#display_version ⇒ String
Readable version string, e.g. "1.2.3". On Android, strictly the same as "
version name". On iOS, strictly the same as "version number" or
CFBundleShortVersionString.
Corresponds to the JSON property displayVersion
1522 1523 1524 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1522 def display_version @display_version end |
#tracks ⇒ Array<Google::Apis::FirebasecrashlyticsV1alpha::PlayTrack>
Indicates releases which have artifacts that are currently available in the
Play Store to the target audience of the track. Versions may be available in
multiple tracks.
Corresponds to the JSON property tracks
1529 1530 1531 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1529 def tracks @tracks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1536 1537 1538 1539 1540 1541 |
# File 'lib/google/apis/firebasecrashlytics_v1alpha/classes.rb', line 1536 def update!(**args) @build_version = args[:build_version] if args.key?(:build_version) @display_name = args[:display_name] if args.key?(:display_name) @display_version = args[:display_version] if args.key?(:display_version) @tracks = args[:tracks] if args.key?(:tracks) end |